@@ -1,7 +1,7 @@
 #!/usr/bin/env python
 # coding: utf-8
 
-# In[423]:
+# In[560]:
 
 
 try:
@@ -12,10 +12,10 @@ except:
         pass
 
 
-# In[422]:
+# In[559]:
 
 
-version = '0.98'
+version = '0.99'
 
 import re
 import tempfile
@@ -33,7 +33,7 @@ import time
 
 # # Helper Functions
 
-# In[286]:
+# In[427]:
 
 
 def is_testing():
@@ -43,7 +43,7 @@ def is_testing():
         return False
 
 
-# In[287]:
+# In[428]:
 
 
 def isnotebook():
@@ -54,7 +54,7 @@ def isnotebook():
     return False
 
 
-# In[288]:
+# In[429]:
 
 
 def testPrint(*args):
@@ -64,7 +64,7 @@ def testPrint(*args):
 
 # # Inspect
 
-# In[289]:
+# In[430]:
 
 
 import inspect
@@ -76,7 +76,7 @@ def debugFunctionName():
     return inspect.stack()[1][3]
 
 
-# In[290]:
+# In[431]:
 
 
 debugGetFileName(), debugGetLineNumber(), debugFunctionName()
@@ -84,7 +84,7 @@ debugGetFileName(), debugGetLineNumber(), debugFunctionName()
 
 # # Shell
 
-# In[291]:
+# In[432]:
 
 
 def shell(cmd):
@@ -97,7 +97,7 @@ def shell(cmd):
     return out
 
 
-# In[292]:
+# In[433]:
 
 
 shell_template = """/bin/bash << EOF 2>&1
@@ -119,13 +119,13 @@ def bash(cmd, lineList=True):
 
 # # Timing
 
-# In[293]:
+# In[434]:
 
 
 timeSinceLastCallDict = {}
 
 
-# In[294]:
+# In[435]:
 
 
 def timeSinceLastCall(name):
@@ -138,14 +138,14 @@ def timeSinceLastCall(name):
     return name + ": " + time_s
 
 
-# In[295]:
+# In[436]:
 
 
 if is_testing():
     print(timeSinceLastCall('test marker'))
 
 
-# In[296]:
+# In[437]:
 
 
 import time
@@ -173,7 +173,7 @@ if is_testing():
 
 # # Requiremtns
 
-# In[297]:
+# In[438]:
 
 
 requirements = []
@@ -205,7 +205,7 @@ import yaml
 
 # # Strings
 
-# In[298]:
+# In[439]:
 
 
 def sFloat0(f): return "{:0.0f}".format(f)
@@ -235,7 +235,7 @@ if is_testing():
     print(sFloatSci5(1.234567))
 
 
-# In[299]:
+# In[440]:
 
 
 def strUuid4():
@@ -246,14 +246,14 @@ def strUuid4():
     return uuid
 
 
-# In[300]:
+# In[441]:
 
 
 if is_testing():
     print(strUuid4())
 
 
-# In[301]:
+# In[442]:
 
 
 def strRand(n, num=True, upperCase=True, lowerCase=True):
@@ -265,7 +265,7 @@ def strRand(n, num=True, upperCase=True, lowerCase=True):
     return ''.join(random.choice(pool) for _ in range(n))
 
 
-# In[302]:
+# In[443]:
 
 
 if is_testing():
@@ -274,7 +274,7 @@ if is_testing():
     print(strRand(20, upperCase=False, lowerCase=False))
 
 
-# In[303]:
+# In[444]:
 
 
 def strMd5Pickle4(obj):
@@ -284,14 +284,14 @@ def strMd5Pickle4(obj):
     return md5.hexdigest()
 
 
-# In[304]:
+# In[445]:
 
 
 if is_testing():
     print(strMd5Pickle4(['a', 'b']))
 
 
-# In[305]:
+# In[446]:
 
 
 def strMd5String(s):
@@ -300,7 +300,7 @@ def strMd5String(s):
     return md5.hexdigest()
 
 
-# In[306]:
+# In[447]:
 
 
 if is_testing():
@@ -309,7 +309,7 @@ if is_testing():
 
 # # Multiprocess / Thread
 
-# In[307]:
+# In[448]:
 
 
 def mapThread(func, args, n=8):
@@ -334,14 +334,14 @@ if is_testing():
 
 # # Lists
 
-# In[308]:
+# In[449]:
 
 
 def liChunks(l, chunk_size):
     return [l[i:i + chunk_size] for i in range(0, len(l), chunk_size)]
 
 
-# In[309]:
+# In[450]:
 
 
 if is_testing():
@@ -350,7 +350,7 @@ if is_testing():
     print(liChunks(['a', 'b', 'c', 'd', 'e', 'f'], 3))
 
 
-# In[310]:
+# In[451]:
 
 
 def liSplit(a, number_of_splits):
@@ -358,7 +358,7 @@ def liSplit(a, number_of_splits):
     return [a[start:end] for start, end in zip(idxs[:-1], idxs[1:])]
 
 
-# In[311]:
+# In[452]:
 
 
 if is_testing():
@@ -370,7 +370,7 @@ if is_testing():
     print(liSplit(['a', 'b', 'c', 'd', 'e'], 6))
 
 
-# In[312]:
+# In[453]:
 
 
 def liJoin(l):
@@ -380,14 +380,14 @@ def liJoin(l):
     return out
 
 
-# In[313]:
+# In[454]:
 
 
 if is_testing():
     print(liJoin([['a', 'b', 'c'], ['d', 'e', 'f']]))
 
 
-# In[314]:
+# In[455]:
 
 
 def liFlatten(l):
@@ -404,7 +404,7 @@ def liFlatten(l):
         return l
 
 
-# In[315]:
+# In[456]:
 
 
 if is_testing():
@@ -414,7 +414,7 @@ if is_testing():
 
 # # List of Strings
 
-# In[316]:
+# In[457]:
 
 
 regex_cache = {}
@@ -424,35 +424,35 @@ def sListFilter(l, re_include=".*", re_exclude='^\b$'):
     return [e for e in l if regex_cache[re_include].search(e) and not regex_cache[re_exclude].search(e)]
 
 
-# In[317]:
+# In[458]:
 
 
 if is_testing():
     sListFilter(['good x', 'other good x', 'without the letter before y'])
 
 
-# In[318]:
+# In[459]:
 
 
 if is_testing():
     print(sListFilter(['good x', 'other good x', 'without the letter before y'], re_include='x'))
 
 
-# In[319]:
+# In[460]:
 
 
 if is_testing():
     print(sListFilter(['not enough x', 'enough xx', 'enough xx and also z'], re_include='xx+'))
 
 
-# In[320]:
+# In[461]:
 
 
 if is_testing():
     print(sListFilter(['not enough x', 'enough xx', 'enough xx and also z'], re_include='xx+', re_exclude='z'))
 
 
-# In[321]:
+# In[462]:
 
 
 def lCsv(l, force_oneline=False):
@@ -468,21 +468,21 @@ def lCsv(l, force_oneline=False):
     return ", ".join([str(e) for e in l])
 
 
-# In[322]:
+# In[463]:
 
 
 if is_testing():
     print(lCsv(['a', 'b', 1, 3.14]))
 
 
-# In[323]:
+# In[464]:
 
 
 if is_testing():
     print(lCsv([['a', 'b'], 1, 3.14]))
 
 
-# In[324]:
+# In[465]:
 
 
 if is_testing():
@@ -491,7 +491,7 @@ if is_testing():
 
 # # Text files
 
-# In[325]:
+# In[466]:
 
 
 def txtread(path):
@@ -512,7 +512,7 @@ def txtwrite(path, txt):
             return f.write(txt)
 
 
-# In[326]:
+# In[467]:
 
 
 if is_testing():
@@ -521,21 +521,21 @@ if is_testing():
 
 # # YAML files
 
-# In[327]:
+# In[468]:
 
 
 def yamlwrite(path, obj):
     txtwrite(path, yaml.dump(obj))
 
 
-# In[328]:
+# In[469]:
 
 
 def yamlread(path):
     return yaml.safe_load(txtread(path=path))
 
 
-# In[329]:
+# In[470]:
 
 
 if is_testing():
@@ -548,7 +548,7 @@ if is_testing():
 
 # # List of Strings
 
-# In[330]:
+# In[471]:
 
 
 regex_cache = {}
@@ -560,35 +560,35 @@ def sListFilter(listOfStrings, re_include=".*", re_exclude='^\b$'):
 
 # ### Examples
 
-# In[331]:
+# In[472]:
 
 
 if is_testing():
     print(sListFilter(['good x', 'other good x', 'without the letter before y']))
 
 
-# In[332]:
+# In[473]:
 
 
 if is_testing():
     print(sListFilter(['good x', 'other good x', 'without the letter before y'], re_include='x'))
 
 
-# In[333]:
+# In[474]:
 
 
 if is_testing():
     print(sListFilter(['not enough x', 'enough xx', 'enough xx and also z'], re_include='xx+'))
 
 
-# In[334]:
+# In[475]:
 
 
 if is_testing():
     print(sListFilter(['not enough x', 'enough xx', 'enough xx and also z'], re_include='xx+', re_exclude='z'))
 
 
-# In[335]:
+# In[476]:
 
 
 if is_testing():
@@ -597,7 +597,7 @@ if is_testing():
 
 # # GCP Google Cloud Platform
 
-# In[336]:
+# In[477]:
 
 
 import warnings
@@ -621,7 +621,7 @@ def _gsBlob(path):
     return blob
 
 
-# In[337]:
+# In[478]:
 
 
 def gsGsToHttp(path):
@@ -631,7 +631,7 @@ def gsHttpToGs(path):
     return path.replace("https://storage.cloud.google.com/", "gs://").split("?")[0] # "?" is for possible "?authuser=0"
 
 
-# In[338]:
+# In[479]:
 
 
 def gsLs(path):
@@ -641,7 +641,7 @@ def gsLs(path):
     return ['gs://' + bucket + '/' + blob.name for blob in client.list_blobs(prefix=prefix)]
 
 
-# In[339]:
+# In[480]:
 
 
 def gsExists(path):
@@ -651,7 +651,7 @@ def gsExists(path):
     return client.blob(prefix).exists()
 
 
-# In[340]:
+# In[481]:
 
 
 def gsUploadFile(gsPath, path):
@@ -659,7 +659,7 @@ def gsUploadFile(gsPath, path):
     blob.upload_from_filename(path)
 
 
-# In[341]:
+# In[482]:
 
 
 def gsTxtread(path):
@@ -671,7 +671,7 @@ def gsTxtread(path):
     return blob.download_as_string().decode()
 
 
-# In[342]:
+# In[483]:
 
 
 def gsTxtwrite(path, s):
@@ -679,7 +679,7 @@ def gsTxtwrite(path, s):
     return blob.upload_from_string(s)
 
 
-# In[343]:
+# In[484]:
 
 
 def gsImwrite(path, img):
@@ -688,7 +688,7 @@ def gsImwrite(path, img):
     blob.upload_from_string(encimg.tobytes())
 
 
-# In[344]:
+# In[485]:
 
 
 def gsImread(path):
@@ -697,7 +697,7 @@ def gsImread(path):
     return cv2.imdecode(raw, 1)[:, :, [2, 1, 0]]
 
 
-# In[345]:
+# In[486]:
 
 
 def gsPklWrite(path, obj):
@@ -705,7 +705,7 @@ def gsPklWrite(path, obj):
     return blob.upload_from_string(pickle.dumps(obj, protocol=4))
 
 
-# In[346]:
+# In[487]:
 
 
 def gsPklRead(path):
@@ -715,7 +715,7 @@ def gsPklRead(path):
 
 # # Pickle
 
-# In[347]:
+# In[488]:
 
 
 def pklwrite(path, obj):
@@ -728,7 +728,7 @@ def pklwrite(path, obj):
             return pickle.dump(obj, f, protocol=4)
 
 
-# In[348]:
+# In[489]:
 
 
 def pklread(path):
@@ -739,7 +739,7 @@ def pklread(path):
             return pickle.load(f)
 
 
-# In[349]:
+# In[490]:
 
 
 if is_testing():
@@ -752,7 +752,7 @@ if is_testing():
 
 # # Images
 
-# In[350]:
+# In[491]:
 
 
 def _imreadSsh(path):
@@ -795,10 +795,16 @@ def imwrite(path, img, jpeg_quality=95):
 
 def imjoin(imgs, axis=1, pad=0):
     if pad > 0:
+        if axis == 0:
+            right=pad
+            bottom=0
+        elif axis == 1:
+            right=0
+            bottom=pad
         imgs_out = []
         for idx, img in enumerate(imgs):
             if idx < len(imgs) - 1:
-                imgs_out.append(impad(img, right=pad))
+                imgs_out.append(impad(img, right=right, bottom=bottom))
             else:
                 imgs_out.append(img)
         imgs = imgs_out
@@ -813,7 +819,7 @@ def impad(img, top=0, bottom=0, left=0, right=0, color=255, mode='constant'):
         raise RuntimeError(f"Mode '{mode}' not found")
 
 
-# In[351]:
+# In[492]:
 
 
 def imscaleNN(img, s):
@@ -825,7 +831,7 @@ def imscaleBic(img, s):
 
 
 
-# In[352]:
+# In[493]:
 
 
 def imshow(array, scale=1, force_nb=False):
@@ -840,14 +846,14 @@ def imshow(array, scale=1, force_nb=False):
         cv2.waitKey()
 
 
-# In[353]:
+# In[494]:
 
 
 def imNewNoise(height, width, scaleNN=1):
     return imscaleNN((255 * np.random.rand(height, width, 3)).astype(np.uint8), scaleNN)
 
 
-# In[354]:
+# In[495]:
 
 
 if is_testing():
@@ -855,7 +861,7 @@ if is_testing():
     imshow(impad(img, bottom=10, right=10, mode='reflect'))
 
 
-# In[355]:
+# In[496]:
 
 
 def imCropUniformBorder(img, color=255):
@@ -894,7 +900,7 @@ if is_testing():
                         raise RuntimeError('Crop did not work for ', i, j, k, l)
 
 
-# In[356]:
+# In[497]:
 
 
 def imDecodeBytes(imBytes):
@@ -905,7 +911,7 @@ def imDecodeBytes(imBytes):
     return img
 
 
-# In[357]:
+# In[498]:
 
 
 #if is_testing():
@@ -913,14 +919,14 @@ def imDecodeBytes(imBytes):
 #    imshow(img)
 
 
-# In[358]:
+# In[499]:
 
 
 #if is_testing():
 #    imshow('http://via.placeholder.com/70.png')
 
 
-# In[359]:
+# In[500]:
 
 
 if is_testing():
@@ -939,7 +945,7 @@ if is_testing():
         imshow(out_large_interbic)
 
 
-# In[360]:
+# In[501]:
 
 
 def imRepeat(img, height, width):
@@ -953,7 +959,7 @@ def imRepeat(img, height, width):
     return img
 
 
-# In[361]:
+# In[502]:
 
 
 if is_testing():
@@ -961,33 +967,33 @@ if is_testing():
     imshow(imRepeat(img_random_color_3x5, 7, 11), scale=10)
 
 
-# In[362]:
+# In[503]:
 
 
 def imNewWhite(height, width):
     return np.ones((height, width, 3)).astype(np.uint8) * 255
 
 
-# In[363]:
+# In[504]:
 
 
 if is_testing(): imshow(imNewWhite(10, 500) - 30)
 
 
-# In[364]:
+# In[505]:
 
 
 def imNewBlack(height, width):
     return np.zeros((height, width, 3)).astype(np.uint8)
 
 
-# In[365]:
+# In[506]:
 
 
 if is_testing(): imshow(imNewBlack(10, 500))
 
 
-# In[366]:
+# In[507]:
 
 
 def imAddNoiseGauss(img, std):
@@ -999,7 +1005,7 @@ def imAddNoiseGauss(img, std):
 if is_testing(): imshow(imAddNoiseGauss(imNewWhite(150, 150), 30))
 
 
-# In[367]:
+# In[508]:
 
 
 if is_testing():
@@ -1007,7 +1013,7 @@ if is_testing():
     imshow('/tmp/img.jpg')
 
 
-# In[368]:
+# In[509]:
 
 
 def imJpgDegradation(img, quality):
@@ -1020,7 +1026,7 @@ def imJpgDegradation(img, quality):
 #if is_testing(): imshow(imJpgDegradation(imread('http://via.placeholder.com/150.png'), 15))
 
 
-# In[369]:
+# In[510]:
 
 
 def imCropCenter(img, size):
@@ -1035,35 +1041,35 @@ def imCropCenter(img, size):
     return img[h_start:h_end, w_start:w_end]
 
 
-# In[370]:
+# In[511]:
 
 
 #if is_testing(): 
 #    imshow(imCropCenter(imread('http://via.placeholder.com/40.png'), 10))
 
 
-# In[371]:
+# In[512]:
 
 
 #if is_testing(): 
 #    imshow(imCropCenter(imread('http://via.placeholder.com/40.png'), 49))
 
 
-# In[372]:
+# In[513]:
 
 
 #if is_testing(): 
 #    imshow(imCropCenter(imread('http://via.placeholder.com/40.png'), 50))
 
 
-# In[373]:
+# In[514]:
 
 
 #if is_testing(): 
 #    imshow(imCropCenter(imread('http://via.placeholder.com/40.png'), 100))
 
 
-# In[374]:
+# In[515]:
 
 
 def imCropRandom(img, size, auto_size=True):
@@ -1086,7 +1092,7 @@ def imCropRandom(img, size, auto_size=True):
     return img[h_start:h_end, w_start:w_end]
 
 
-# In[375]:
+# In[516]:
 
 
 #if is_testing(): 
@@ -1096,7 +1102,7 @@ def imCropRandom(img, size, auto_size=True):
 #    imshow(imCropRandom(imread('http://via.placeholder.com/40.png'), 41))
 
 
-# In[376]:
+# In[517]:
 
 
 def imGallery(imgs, pad=0, n_cols=None, n_rows=None):
@@ -1140,7 +1146,7 @@ def imGallery(imgs, pad=0, n_cols=None, n_rows=None):
     return out
 
 
-# In[377]:
+# In[518]:
 
 
 if is_testing():
@@ -1148,7 +1154,7 @@ if is_testing():
     listOfDummyImagesBlackToWhite = [imNewBlack(10, 10) + 25 * i for i in range(10)]
 
 
-# In[378]:
+# In[519]:
 
 
 if is_testing():
@@ -1162,7 +1168,7 @@ if is_testing():
     imshow(imGallery(listOfDummyImagesBlackToWhite[:10], pad=1, n_rows=2))
 
 
-# In[379]:
+# In[520]:
 
 
 #if is_testing():
@@ -1170,7 +1176,7 @@ if is_testing():
 #    imshow(imGallery([img40x20, img40x20, img40x20], pad=1))
 
 
-# In[380]:
+# In[521]:
 
 
 def imAddTextHeader(img, text, h=None, size=None):
@@ -1207,7 +1213,7 @@ if is_testing():
 
 # # Video
 
-# In[381]:
+# In[522]:
 
 
 #def imgsToVid(imgs, file_name='out.avi'):
@@ -1227,13 +1233,13 @@ if is_testing():
 #imgsToVid(frames, 'test.avi')
 
 
-# In[382]:
+# In[523]:
 
 
 #ffmpeg -framerate 1/5 -i img%03d.png -c:v libx264 -r 30 -pix_fmt yuv420p out.mp4
 
 
-# In[421]:
+# In[524]:
 
 
 def imsToMp4(path, imgs, time_per_image, frame_rate_output_video=30, verbose=0):
@@ -1253,7 +1259,7 @@ if is_testing():
 
 # # pytorch
 
-# In[384]:
+# In[525]:
 
 
 def ptT(img_np_uint8):
@@ -1270,7 +1276,7 @@ def ptUint8(img_tensor):
     
 
 
-# In[385]:
+# In[526]:
 
 
 if is_testing():
@@ -1282,7 +1288,7 @@ if is_testing():
 
 # # Files
 
-# In[386]:
+# In[527]:
 
 
 def _fiFindByWildcardSsh(wildcard):
@@ -1303,7 +1309,7 @@ def fiFindImgs(dir_path, recursive=False, ext='png'):
     return fiFindByWildcard(wildcard)
 
 
-# In[387]:
+# In[528]:
 
 
 if is_testing():
@@ -1332,7 +1338,7 @@ if is_testing():
         imshow(imGallery(imgs))
 
 
-# In[388]:
+# In[529]:
 
 
 def fiRemove(path):
@@ -1360,7 +1366,7 @@ def fiAgeHours(path):
     return (time.time() - os.stat(path)[stat.ST_MTIME]) / 3600
 
 
-# In[389]:
+# In[530]:
 
 
 if is_testing():
@@ -1392,7 +1398,7 @@ if is_testing():
         print("files: " + "\n".join(fiFindByWildcard(os.path.join(d, "**", "*"))))
 
 
-# In[390]:
+# In[531]:
 
 
 def fiUnzip(zip_path, out_dir=None, remove=False):
@@ -1407,7 +1413,7 @@ def fiUnzip(zip_path, out_dir=None, remove=False):
         zip.extractall(out_dir)
 
 
-# In[391]:
+# In[532]:
 
 
 def fiJoin(*args):
@@ -1419,7 +1425,7 @@ if is_testing():
 
 # # Jupyter
 
-# In[392]:
+# In[533]:
 
 
 def jnSettings():
@@ -1430,7 +1436,7 @@ if is_testing():
     jnSettings()
 
 
-# In[393]:
+# In[534]:
 
 
 def jnNbFullWidth():
@@ -1444,7 +1450,7 @@ def jnPandasSettings():
     pd.set_option('display.max_colwidth', 100000)
 
 
-# In[394]:
+# In[535]:
 
 
 def jnImageRenderingPixelated():
@@ -1456,7 +1462,7 @@ def jnImageRenderingAuto():
     display(HTML('<style type = text/css> img { image-rendering: auto; } </style>'))
 
 
-# In[395]:
+# In[536]:
 
 
 def jnDefault():
@@ -1474,7 +1480,7 @@ if is_testing():
 
 
 
-# In[396]:
+# In[537]:
 
 
 def jnHtmlRow(strList, width=100):
@@ -1487,7 +1493,7 @@ if is_testing():
     
 
 
-# In[397]:
+# In[538]:
 
 
 def jnImgToHtmlB64(img):
@@ -1522,7 +1528,7 @@ def jnImageRow(imgs, names=None, width=100, external=False, title_img=None, titl
     display(HTML(html))
 
 
-# In[398]:
+# In[539]:
 
 
 if is_testing():
@@ -1530,7 +1536,7 @@ if is_testing():
    
 
 
-# In[399]:
+# In[540]:
 
 
 if is_testing():
@@ -1540,7 +1546,7 @@ if is_testing():
     jnImageRow(imgs, external=True, title='test')
 
 
-# In[400]:
+# In[541]:
 
 
 
@@ -1550,7 +1556,7 @@ if is_testing():
 
 # # GIT
 
-# In[401]:
+# In[542]:
 
 
 def gitGetHash():
@@ -1560,7 +1566,7 @@ if is_testing():
     print(gitGetHash())
 
 
-# In[402]:
+# In[543]:
 
 
 def gitGetBranch():
@@ -1570,7 +1576,7 @@ if is_testing():
     print(gitGetBranch())
 
 
-# In[403]:
+# In[544]:
 
 
 def gitGetMessage():
@@ -1580,7 +1586,7 @@ if is_testing():
     print(gitGetMessage())
 
 
-# In[404]:
+# In[545]:
 
 
 def gitGetAllFiles():
@@ -1590,7 +1596,7 @@ if is_testing():
     print(gitGetAllFiles())
 
 
-# In[405]:
+# In[546]:
 
 
 def gitListByTime(path=None):
@@ -1606,7 +1612,7 @@ if is_testing():
     print(gitListByTime()[-3:])
 
 
-# In[406]:
+# In[547]:
 
 
 def gitTime(path):
@@ -1617,7 +1623,7 @@ if is_testing():
     print(gitTime("__init__.py"))
 
 
-# In[407]:
+# In[548]:
 
 
 def gitTimeRaw(path):
@@ -1628,7 +1634,7 @@ if is_testing():
     print(gitTimeRaw("__init__.py"))
 
 
-# In[408]:
+# In[549]:
 
 
 def shellSortDirsBySize():
@@ -1640,14 +1646,14 @@ if is_testing():
 
 # # Package Files
 
-# In[409]:
+# In[550]:
 
 
 if is_testing():
     package_files = {}
 
 
-# In[410]:
+# In[551]:
 
 
 def shell(cmd):
@@ -1655,7 +1661,7 @@ def shell(cmd):
     return result.stdout.decode()
 
 
-# In[411]:
+# In[552]:
 
 
 if is_testing():
@@ -1687,7 +1693,7 @@ setup(
 )""".format(requirements=", ".join(["'" + r + "'" for r in requirements]), version=version)
 
 
-# In[412]:
+# In[553]:
 
 
 if is_testing():
@@ -1697,7 +1703,7 @@ description-file = README.md
 """
 
 
-# In[413]:
+# In[554]:
 
 
 if is_testing():
@@ -1720,14 +1726,14 @@ OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
 SOFTWARE."""
 
 
-# In[414]:
+# In[555]:
 
 
 if is_testing():
     package_files['README.md'] = ""
 
 
-# In[415]:
+# In[556]:
 
 
 if is_testing():
@@ -1738,7 +1744,7 @@ if is_testing():
     print(output.strip(), 'Version correct: ', output.strip() == version, "(", output.strip(), version, ")")
 
 
-# In[416]:
+# In[557]:
 
 
 if is_testing():
@@ -1749,7 +1755,7 @@ lx/__init__.py
 """
 
 
-# In[417]:
+# In[558]:
 
 
 if is_testing():
